clear all
set more off

/*
Construct average tariff from trade flow and tariff data, by source/destination and SITC 4-digit code. 

Note: This program will not run without files Tariff_2004.dta and wtf_2004_REV_v2.dta. See file data_description.pdf for data sources for Tariff_2004.dta and wtf_2004_REV_v2.dta.

*/

***************************************************************
use "/Users/sina/Dropbox/Documents/Post JM work/My Papers/JMP Re-Revision/ReStud/Final Revision/Submission materials/Tariff_2004.dta", clear
* Generate the minimum between the preferential and MFN tariffs
egen min_tarif = rowmin(t1 t1_pref)
* Drop all pairs for which the exporting countries is not identified
drop if eiso==""
* Drop missing data, to reduce the size of the data set
drop if min_tarif==.
* Changing variables names to merge with trade data
rename iiso iiso3
rename eiso eiso3
merge m:1 iiso3 eiso3 sitc4 using "/Users/sina/Dropbox/Documents/Post JM work/My Papers/JMP Re-Revision/ReStud/Final Revision/Submission materials/wtf_2004_REV_v2.dta"
keep if _merge==3
drop _merge
* Keep only needed variables
keep iiso3 sitc4 eiso3 min_tarif value

* Weighted tariff
* Total_trade= total across all countries by importer
bysort iiso3 : egen total_trade=total(value)
* share of each exporting countries
gen share=value/total_trade
* Multiply each min_tarif by the share
gen weighted_tarif=min_tarif*share
* Sum of all components per importing country
bysort iiso3: egen  weighted_min_tariff=total(weighted_tarif)

collapse weighted_min_tariff, by(iiso3)
rename weighted_min_tariff weighted_sitc4_tariff
rename iiso3 country_code 
save "/Users/sina/Dropbox/Documents/Post JM work/My Papers/JMP Re-Revision/ReStud/Final Revision/Submission materials/mean_tariff.dta", replace
